---
title: <span class="badge object-type-scalar"></span> Millisievert
---
# <span class="badge object-type-scalar"></span> Millisievert

Radiation: milliSievert (mSv)

## Definition

```python
# Radiation: milliSievert (mSv)
Millisievert: typing.Literal["radmsv"] = "radmsv"
```
